@@ -1,6 +1,6 @@
 from . import neural_networks
 from . import datasets
 from . import unsupervised
+from . import tokenizers
 from .utilities import *
-from ._model_loading import load
 from ._info import __version__, __author__
