@@ -1,9 +1,9 @@
-from ._aquarium import aquarium
+from . import generators
 from ._boston_housing import boston_housing
 from ._cityscapes import cityscapes
 from ._fashion_mnist import fashion_mnist
 from ._iris import iris
-from ._savannah import savannah
 from ._titanic import titanic
 from ._sentence_pairs import sentence_pairs
 from ._airline_tweets import airline_tweets
+from ._download import download_bytes
