@@ -1,8 +1,9 @@
+import pathlib
 from ._download import download
 
 
 def boston_housing(directory: str):
     """downloads 'boston_housing.csv' in the given directory"""
-    download(directory, "boston_housing.csv",
+    download(pathlib.Path(directory) / "boston_housing.csv",
              "https://drive.google.com/file/d"
              "/1fTWYixdKF4tWyhD3V-qCDSZmReN_6LzP/view?usp=sharing")
