@@ -1,4 +1,4 @@
 from ._cross_validation import split, kfold
 from ._metrics import MSE, RMSE, R2, accuracy, confusion_matrix, GPU_info
-from ._ploting import plot_fitting, plot_bounding_boxes, plot_matrix
-from ._decorators import document
+from ._ploting import plot_losses, plot_fitting, plot_bounding_boxes, plot_matrix
+# from ._decorators import document
